@@ -516,11 +516,11 @@ class LaunchStackTask(HastexoTask):
             port = 3389
 
         connected = False
-        conn = None
+        s = socket.socket()
+        s.settimeout(self.get_sleep_timeout())
         while not connected:
             try:
-                conn = socket.create_connection((stack_ip, port),
-                                                self.get_sleep_timeout())
+                s.connect((stack_ip, port))
             except SoftTimeLimitExceeded:
                 raise
             except Exception:
@@ -528,8 +528,7 @@ class LaunchStackTask(HastexoTask):
             else:
                 connected = True
             finally:
-                if conn:
-                    conn.close()
+                s.close()
 
     def check_stack(self, stack_outputs, was_resumed, provider):
         """
@@ -656,7 +655,6 @@ class SuspendStackTask(HastexoTask):
                     stack.hook_events and
                     isinstance(stack.hook_events, dict) and
                     stack.hook_events.get("suspend", False)):
-                ssh = None
                 try:
                     # If there's a suspend hook, execute it.
                     logger.info("Fetching pre-suspend hook [%s] for stack "
@@ -676,8 +674,10 @@ class SuspendStackTask(HastexoTask):
                     logger.error("Error running pre-suspend hook for stack "
                                  "[%s]: %s" % (stack.name, error_msg))
                 finally:
-                    if ssh:
+                    try:
                         ssh.close()
+                    except Exception:
+                        pass
 
             # Suspend stack
             logger.info("Suspending stack [%s]." % stack.name)
@@ -769,7 +769,6 @@ class DeleteStackTask(HastexoTask):
                         logger.info("Executing pre-delete hook for stack [%s] "
                                     "at [%s]." % (stack.name, stack.ip))
 
-                        ssh = None
                         try:
                             script = read_from_contentstore(stack.course_id,
                                                             stack.hook_script)
@@ -782,8 +781,7 @@ class DeleteStackTask(HastexoTask):
                                          "for stack [%s]: %s" %
                                          (stack.name, str(e)))
                         finally:
-                            if ssh:
-                                ssh.close()
+                            ssh.close()
 
                 try:
                     provider_stack = provider.delete_stack(stack.name)
@@ -820,12 +818,12 @@ class CheckStudentProgressTask(HastexoTask):
         for key, value in kwargs.items():
             setattr(self, key, value)
 
-        ssh = None
         try:
             # Open SSH connection to the public facing node
             ssh = ssh_to(self.stack_user_name,
                          self.stack_ip,
                          self.stack_key)
+
             # Run tests on the stack
             res = self.run_tests(ssh)
         except (RemoteExecTimeout, SoftTimeLimitExceeded):
@@ -834,9 +832,8 @@ class CheckStudentProgressTask(HastexoTask):
                 'error': True
             }
         finally:
-            if ssh:
-                # Close the connection
-                ssh.close()
+            # Close the connection
+            ssh.close()
 
         return res
 
